;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "vscode-dark-plus-theme" "20260420.8"
  "Default Visual Studio Code Dark+ theme."
  ()
  :url "https://github.com/ianpan870102/vscode-dark-plus-emacs-theme"
  :commit "082b012d203fed17d54b4a3b7437db545f15ddbb"
  :revdesc "082b012d203f")
